==> zio-aws-ec2_2.13-5.17.127.2-sources.jar: zio/aws/ec2/model/ModifyVpcEndpointServicePayerResponsibilityResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ModifyVpcEndpointServicePayerResponsibilityResponse(
    returnValue: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse = {
    import ModifyVpcEndpointServicePayerResponsibilityResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse
      .builder()
      .optionallyWith(returnValue.map(value => value: java.lang.Boolean))(
        _.returnValue
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse.ReadOnly =
    zio.aws.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse
      .wrap(buildAwsValue())
}
object ModifyVpcEndpointServicePayerResponsibilityResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse =
      zio.aws.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse(
        returnValue.map(value => value)
      )
    def returnValue: Option[Boolean]
    def getReturnValue: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("returnValue", returnValue)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse
  ) extends zio.aws.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse.ReadOnly {
    override val returnValue: Option[Boolean] =
      scala.Option(impl.returnValue()).map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse
  ): zio.aws.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.19.8.3-sources.jar: zio/aws/ec2/model/ModifyVpcEndpointServicePayerResponsibilityResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifyVpcEndpointServicePayerResponsibilityResponse(
    returnValue: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse = {
    import ModifyVpcEndpointServicePayerResponsibilityResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse
      .builder()
      .optionallyWith(returnValue.map(value => value: java.lang.Boolean))(
        _.returnValue
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse.ReadOnly =
    zio.aws.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse
      .wrap(buildAwsValue())
}
object ModifyVpcEndpointServicePayerResponsibilityResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse =
      zio.aws.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse(
        returnValue.map(value => value)
      )
    def returnValue: Optional[Boolean]
    def getReturnValue: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("returnValue", returnValue)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse
  ) extends zio.aws.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse.ReadOnly {
    override val returnValue: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.returnValue())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse
  ): zio.aws.ec2.model.ModifyVpcEndpointServicePayerResponsibilityResponse.ReadOnly =
    new Wrapper(impl)
}
